@@ -34,6 +34,7 @@
 
 
 
+#include <testVec.h>
 #include <testRoots.h>
 #include <testFun.h>
 #include <testInvert.h>
@@ -44,10 +45,12 @@
 #include <testMatrix.h>
 #include <testExtractEuler.h>
 #include <testExtractSHRT.h>
+#include <testQuat.h>
 #include <testQuatSetRotation.h>
 #include <testQuatSlerp.h>
 #include <testLineAlgo.h>
 #include <testBoxAlgo.h>
+#include <testBox.h>
 
 #include <string.h>
 
@@ -56,6 +59,7 @@
 int
 main (int argc, char *argv[])
 {
+	TEST (testVec);
     TEST (testColor);
     TEST (testShear);
     TEST (testMatrix);
@@ -66,9 +70,12 @@ main (int argc, char *argv[])
     TEST (testRandom);
     TEST (testExtractEuler);
     TEST (testExtractSHRT);
+    TEST (testQuat);
     TEST (testQuatSetRotation);
     TEST (testQuatSlerp);
     TEST (testLineAlgo);
     TEST (testBoxAlgo);
+    TEST (testBox);
+    
     return 0;
 }
